@@ -45,7 +45,9 @@ void onAboutClicked(HildonButton * button, AppData *data) {
 	strcat(infoLabel, "\n");
 	strcat(infoLabel, "\n");
 	strcat(infoLabel, "with contributions by\n");
-	strcat(infoLabel, "<i>hcm</i> (various patches)");
+	strcat(infoLabel, "<i>hcm</i> (various patches)\n");
+	strcat(infoLabel, "<i>thp</i> (hildon themed buttons)\n");
+	strcat(infoLabel, "<i>qwerty12</i> (two min crash)");
 
 	hildon_banner_show_information_with_markup(
 			GTK_WIDGET(data->journeyWindow),
@@ -135,73 +137,45 @@ void onGPSError(LocationGPSDControl *control,gint error, AppData *data)
 	location_gpsd_control_stop(data->currentGPSControl);
 }
 
-/**
- * changed signal handler for GPS
- *
- * Gets current latitude and longitude and then sends to backend to
- * get a list of items
- */
-void onGPSLocation(LocationGPSDevice *device, AppData * data)
-{
-	if (!device)
-		return;
-
-	if (device->fix && device->status == LOCATION_GPS_DEVICE_STATUS_FIX) {
-
-		if (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET) {
-
-			hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->currentDialog), 0);
-
-			struct lconv *lcp = localeconv();
-			gchar *tmp = g_strdup_printf("%f", device->fix->latitude);
-			tmp = stringReplace(tmp, lcp->decimal_point, "");
-			int poslat = atoi(tmp);
-			tmp = g_strdup_printf("%f", device->fix->longitude);
-			tmp = stringReplace(tmp, lcp->decimal_point, "");
-			int poslong =atoi(tmp);
-
-			g_object_unref(device);
-			g_object_unref(data->currentGPSControl);
-			location_gpsd_control_stop(data->currentGPSControl);
-
-			GArray *result = getStationsByGPS(poslong, poslat, data);
-
-			initStationPickerForArray(result, data);
-		}
-	}
-}
-
 /**
  * OnClick Event for a HildonButton
  * Handles start of gps selection
  */
 void onGetStationByGPSClicked(HildonButton * button, AppData *data) {
 
-	data->currentGPSControl = location_gpsd_control_get_default();
-	LocationGPSDevice *device = g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);
-
-	g_object_set(G_OBJECT(data->currentGPSControl), "preferred-method",
-			LOCATION_METHOD_USER_SELECTED, "preferred-interval",
-			LOCATION_INTERVAL_DEFAULT, NULL);
-
-	hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->currentDialog), 1);
-
-	g_signal_connect(device, "changed", G_CALLBACK(onGPSLocation), data);
-	g_signal_connect(data->currentGPSControl, "error-verbose", G_CALLBACK(onGPSError), data);
-
-	location_gpsd_control_start(data->currentGPSControl);
-
-	if ((device->fix->latitude > 0) || (device->fix->latitude < 0)) {
-
-	} else {
-
-		hildon_banner_show_information(GTK_WIDGET(data->journeyWindow), NULL,
-				_("Error with location service"));
-
-		hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->currentDialog), 0);
-		location_gpsd_control_stop(data->currentGPSControl);
-
+	if (!data->currentGPSDevice)
 		return;
+
+	if (data->currentGPSDevice->fix && data->currentGPSDevice->status == LOCATION_GPS_DEVICE_STATUS_FIX) {
+
+		if (data->currentGPSDevice->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET) {
+
+			struct lconv *lcp = localeconv();
+			gchar *tmp = g_strdup_printf("%f", data->currentGPSDevice->fix->latitude);
+			tmp = stringReplace(tmp, lcp->decimal_point, "");
+			int poslat = atoi(tmp);
+			tmp = g_strdup_printf("%f", data->currentGPSDevice->fix->longitude);
+			tmp = stringReplace(tmp, lcp->decimal_point, "");
+			int poslong =atoi(tmp);
+
+			GArray *result = getStationsByGPS(poslong, poslat, data);
+
+			/* nothing found */
+			if (result && !g_array_index(result, gchar*, 0)) {
+
+				hildon_banner_show_information(
+						GTK_WIDGET(data->journeyWindow),
+						NULL,
+						_("No Stations found near your location!"));
+
+			} else {
+
+				initStationPickerForArray(result, data);
+			}
+		}
+	} else {
+		hildon_banner_show_information(GTK_WIDGET(data->journeyWindow), NULL,
+				_("No GPS Fix yet!"));
 	}
 }
 /**
@@ -243,6 +217,58 @@ void onStartSearchClicked(HildonButton * button, AppData *data) {
 	}
 }
 
+/**
+ *
+ * OnClick Event for a HildonButton
+ * Handles start of the departure search
+ */
+void onStartDepartureSearchClicked(HildonButton * button, AppData *data) {
+
+	const gchar *fromText = hildon_button_get_value(HILDON_BUTTON(data->departureFromButton));
+
+	if (strcmp(fromText, "") && strcmp(fromText, _("please select"))) {
+
+		gint optionsSelected = hildon_touch_selector_get_active(
+				HILDON_TOUCH_SELECTOR(data->optionsSelector), 0);
+		gint year;
+		gint month;
+		gint day;
+		gint hour;
+		gint minutes;
+
+		hildon_date_button_get_date(HILDON_DATE_BUTTON(data->departureTimeDateButton),
+				&year, &month, &day);
+
+		hildon_time_button_get_time(HILDON_TIME_BUTTON(data->departureTimeTimeButton),
+				&hour, &minutes);
+
+		/*
+
+		REQTrain_name                                (??)
+		REQTrain_name_filterSelf	1                (??)
+		ao	yes                                      (??)
+		boardType	Abfahrt                          (Or Ankunft/optionsSelected)
+		date	20.03.10                             (Normal Date/departureTimeDateButton)
+		input	m                                    (input string, could come from dropdown in parser / fromText)
+		maxJourneys	10                               (we lock this to 10)
+		productsFilter	1111111111000000             (train types bit mask hard to ALL?)
+		start	Suchen                               (??)
+		time	12:27                                (Normal Time/departureTimeTimeButton)
+
+		ResultInfo *result = getJourneyData((gchar*)fromText, NULL, (gchar*)toText, day, month+1, year, hour, minutes, optionsSelected, data);
+
+		initDepartureResults(result, data);
+
+		*/
+
+	} else {
+
+		hildon_banner_show_information(GTK_WIDGET(data->departureWindow), NULL,
+				_("Please select the station you want to get the Departure informations from."));
+		return;
+	}
+}
+
 /**
  *
  * OnClick Event for a HildonButton
@@ -364,7 +390,7 @@ void initJournyDetails(DetailInfo *details, AppData *data) {
 
 	infoLabel[strlen(infoLabel) -1] = '\0';
 
-	line = gtk_button_new();
+        line = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0);
 	gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
 	gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
 
@@ -441,7 +467,7 @@ void initJournyDetails(DetailInfo *details, AppData *data) {
 
 			infoLabel[strlen(infoLabel) -1] = '\0';
 
-			line = gtk_button_new();
+            line = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0);
 			gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
 			gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
 
@@ -510,7 +536,7 @@ void initJournyResults(ResultInfo *result, AppData *data) {
 	if (result->headerEarlierUrl) {
 
 		/* earlier button */
-		button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+		button = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0);
 			gtk_button_set_label(GTK_BUTTON (button), _("Earlier"));
 
 		/* Attach callback to clicked signal */
@@ -523,7 +549,7 @@ void initJournyResults(ResultInfo *result, AppData *data) {
 	if (result->headerLaterUrl) {
 
 		/* later button */
-		button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+		button = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0);
 		gtk_button_set_label(GTK_BUTTON (button), _("Later"));
 
 		/* Attach callback to clicked signal */
@@ -572,7 +598,7 @@ void initJournyResults(ResultInfo *result, AppData *data) {
 				labelText = g_strdup_printf("<b>%s - %s</b> %s (%s %s)\n%s", value->fromTimeStr, value->toTimeStr, value->trainTypeStr, value->changeStr, transfersStr, value->warningStr);
 			}
 
-			line = gtk_button_new();
+            line = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0);
 			gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
 			gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
 
@@ -658,7 +684,7 @@ void initStationPickerForArray(GArray *result, AppData *data) {
 
 			}
 
-			data->currentTmpPicker = hildon_picker_button_new(HILDON_SIZE_AUTO,
+			data->currentTmpPicker = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 					HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 			hildon_button_set_title(HILDON_BUTTON (data->currentTmpPicker),
 					_("Stations found"));
@@ -703,16 +729,15 @@ void initStationSelectorDialog(AppData *data) {
 	gtk_box_pack_start(GTK_BOX (GTK_DIALOG(data->currentDialog)->vbox),
 			data->currentSearchTextBox, TRUE, TRUE, 0);
 
-	submitButton = gtk_dialog_add_button(GTK_DIALOG(data->currentDialog),
-			_("Search"), 0);
-
-	gpsButton = gtk_dialog_add_button(GTK_DIALOG(data->currentDialog),
-			_("GPS"), 0);
-
+	submitButton = gtk_dialog_add_button(GTK_DIALOG(data->currentDialog), _("Search"), 0);
 
 	g_signal_connect (G_OBJECT (submitButton), "clicked", G_CALLBACK (onSearchStationClicked), data);
 
-	g_signal_connect (G_OBJECT (gpsButton), "clicked", G_CALLBACK (onGetStationByGPSClicked), data);
+	if (data->GPSEnabled)
+	{
+		gpsButton = gtk_dialog_add_button(GTK_DIALOG(data->currentDialog), _("GPS"), 0);
+		g_signal_connect (G_OBJECT (gpsButton), "clicked", G_CALLBACK (onGetStationByGPSClicked), data);
+	}
 
 	g_signal_connect (G_OBJECT (data->currentSearchTextBox), "activate", G_CALLBACK (onSearchStationClicked), data);
 
@@ -739,6 +764,76 @@ void initDepartureMonitorGui(AppData *data) {
 	g_signal_connect (G_OBJECT (data->departureWindow), "destroy",
 			G_CALLBACK (gtk_main_quit), NULL);
 
+	/* create vertical container to stack the other containers vertically and add to main view */
+	data->departureVerticalContainer = gtk_vbox_new(FALSE, 4);
+	gtk_container_add(GTK_CONTAINER(data->departureWindow), data->departureVerticalContainer);
+
+	/* From Button */
+	data->departureFromButton = hildon_button_new_with_text(HILDON_SIZE_AUTO,
+			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL, _("Station"),
+			_("please select"));
+
+	hildon_button_set_style(HILDON_BUTTON(data->departureFromButton),
+			HILDON_BUTTON_STYLE_PICKER);
+
+	g_signal_connect (G_OBJECT (data->departureFromButton), "clicked", G_CALLBACK (onSelectStationClicked), data);
+
+	gtk_box_pack_start(GTK_BOX (data->departureVerticalContainer), data->departureFromButton, TRUE,
+			TRUE, 0);
+
+
+	/* create "time" elements */
+	data->departureTimeContainer = gtk_hbox_new(FALSE, 4);
+
+	data->departureTimeDateButton = hildon_date_button_new(HILDON_SIZE_AUTO,
+			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+
+	hildon_button_set_title(HILDON_BUTTON (data->departureTimeDateButton), _("Date"));
+	gtk_box_pack_start(GTK_BOX (data->departureTimeContainer), data->departureTimeDateButton,
+			TRUE, TRUE, 0);
+
+	data->departureTimeTimeButton = hildon_time_button_new(HILDON_SIZE_AUTO,
+			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+	hildon_button_set_title(HILDON_BUTTON (data->departureTimeTimeButton), _("Time"));
+
+	gtk_box_pack_start(GTK_BOX (data->departureTimeContainer), data->departureTimeTimeButton,
+			TRUE, TRUE, 0);
+
+	gtk_box_pack_start(GTK_BOX (data->departureVerticalContainer), data->departureTimeContainer,
+			TRUE, TRUE, 0);
+
+	/* options button (for the time */
+	data->departureOptionsButton = hildon_picker_button_new(HILDON_SIZE_AUTO,
+			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+	hildon_button_set_title(HILDON_BUTTON (data->departureOptionsButton),
+			_(""));
+
+	data->departureOptionsSelector = hildon_touch_selector_new_text();
+
+	hildon_touch_selector_append_text(
+			HILDON_TOUCH_SELECTOR (data->departureOptionsSelector), _("Arrival"));
+	hildon_touch_selector_append_text(
+			HILDON_TOUCH_SELECTOR (data->departureOptionsSelector), _("Departure"));
+
+	hildon_touch_selector_set_active(
+			HILDON_TOUCH_SELECTOR (data->departureOptionsSelector), 0, 1);
+
+	hildon_picker_button_set_selector(
+			HILDON_PICKER_BUTTON (data->departureOptionsButton),
+			HILDON_TOUCH_SELECTOR (data->departureOptionsSelector));
+
+	gtk_box_pack_start(GTK_BOX (data->departureVerticalContainer), data->departureOptionsButton,
+			TRUE, TRUE, 0);
+
+	/* search button */
+	data->departureSearchButton = gtk_button_new_with_label(_("Search"));
+
+	g_signal_connect(G_OBJECT(data->departureSearchButton), "clicked",
+			G_CALLBACK(onStartDepartureSearchClicked), data);
+
+	gtk_box_pack_start(GTK_BOX (data->departureVerticalContainer), data->departureSearchButton,
+			TRUE, TRUE, 0);
+
 }
 /**
  * Init Journey Planer Gui Window
@@ -773,7 +868,7 @@ void initJourneyPlanerGui(AppData *data) {
 			TRUE, 0);
 	gtk_widget_set_usize(data->fromLabel, 100, 10);
 
-	data->fromButton = hildon_button_new_with_text(HILDON_SIZE_AUTO,
+	data->fromButton = hildon_button_new_with_text(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL, _("Station"),
 			_("please select"));
 
@@ -796,7 +891,7 @@ void initJourneyPlanerGui(AppData *data) {
 			0);
 	gtk_widget_set_usize(data->toLabel, 100, 10);
 
-	data->toButton = hildon_button_new_with_text(HILDON_SIZE_AUTO,
+	data->toButton = hildon_button_new_with_text(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL, _("Station"),
 			_("please select"));
 
@@ -814,7 +909,7 @@ void initJourneyPlanerGui(AppData *data) {
 	gtk_box_pack_start(GTK_BOX(data->stationsVContainer), data->stationsHContainer, TRUE, TRUE, 0);
 
 	/* create swap button */
-	data->swapButton = gtk_button_new_with_label(_("\xe2\x86\x95"));
+    data->swapButton = gtk_button_new_with_label("\xe2\x86\x95");
 	g_signal_connect(G_OBJECT(data->swapButton), "clicked", G_CALLBACK(onSwapClicked), data);
 	gtk_box_pack_start(GTK_BOX(data->stationsVContainer), data->swapButton, FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(data->verticalContainer), data->stationsVContainer, TRUE, TRUE, 0);
@@ -822,14 +917,14 @@ void initJourneyPlanerGui(AppData *data) {
 	/* create "time" elements */
 	data->timeContainer = gtk_hbox_new(FALSE, 4);
 
-	data->timeDateButton = hildon_date_button_new(HILDON_SIZE_AUTO,
+	data->timeDateButton = hildon_date_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 
 	hildon_button_set_title(HILDON_BUTTON (data->timeDateButton), _("Date"));
 	gtk_box_pack_start(GTK_BOX (data->timeContainer), data->timeDateButton,
 			TRUE, TRUE, 0);
 
-	data->timeTimeButton = hildon_time_button_new(HILDON_SIZE_AUTO,
+	data->timeTimeButton = hildon_time_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 	hildon_button_set_title(HILDON_BUTTON (data->timeTimeButton), _("Time"));
 
@@ -840,7 +935,7 @@ void initJourneyPlanerGui(AppData *data) {
 			TRUE, TRUE, 0);
 
 	/* options button (for the time */
-	data->optionsButton = hildon_picker_button_new(HILDON_SIZE_AUTO,
+	data->optionsButton = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 			HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 	hildon_button_set_title(HILDON_BUTTON (data->optionsButton),
 			_("Use selected date/time as"));
@@ -863,7 +958,8 @@ void initJourneyPlanerGui(AppData *data) {
 			TRUE, TRUE, 0);
 
 	/* search button */
-	data->searchButton = gtk_button_new_with_label(_("Search"));
+	data->searchButton = hildon_button_new_with_text(HILDON_SIZE_THUMB_HEIGHT | HILDON_SIZE_AUTO_WIDTH, 0,
+	                _("Search"), NULL);
 
 	g_signal_connect(G_OBJECT(data->searchButton), "clicked",
 			G_CALLBACK(onStartSearchClicked), data);
@@ -900,16 +996,18 @@ void initMainWindowsMenu(AppData *data) {
 	g_signal_connect_after (button, "clicked", G_CALLBACK (onJourneyPlannerClicked), data);
 
 	/*
+
 	button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO, GTK_RADIO_BUTTON(button));
 	gtk_button_set_label(GTK_BUTTON (button), _("Departures"));
 	hildon_app_menu_add_filter(menu, GTK_BUTTON (button));
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON (button), FALSE);
+
 	*/
 
 	/* Attach callback to clicked signal */
 	/*
-	 * g_signal_connect_after (button, "clicked", G_CALLBACK (onDepartureMonitorClicked), data);
- 	 */
+		g_signal_connect_after (button, "clicked", G_CALLBACK (onDepartureMonitorClicked), data);
+	*/
 
 	gtk_widget_show_all(GTK_WIDGET (menu));
 
@@ -930,6 +1028,40 @@ void initTestElements(AppData *data) {
 						"Augsburg Hbf");
 }
 
+/**
+ * Inits the GPS System
+ */
+void initGPS(AppData *data) {
+
+	data->currentGPSControl = location_gpsd_control_get_default();
+	data->currentGPSDevice = g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);
+
+	g_object_set(G_OBJECT(data->currentGPSControl), "preferred-method",
+			LOCATION_METHOD_USER_SELECTED, "preferred-interval",
+			LOCATION_INTERVAL_DEFAULT, NULL);
+
+	g_signal_connect(data->currentGPSControl, "error-verbose", G_CALLBACK(onGPSError), data);
+
+	location_gpsd_control_start(data->currentGPSControl);
+
+	if ((data->currentGPSDevice->fix->latitude > 0) || (data->currentGPSDevice->fix->latitude < 0)) {
+
+		data->GPSEnabled = 1;
+
+	} else {
+
+		data->GPSEnabled = 0;
+
+		hildon_banner_show_information(GTK_WIDGET(data->journeyWindow), NULL,
+				_("GPS not available!"));
+
+		location_gpsd_control_stop(data->currentGPSControl);
+
+		return;
+	}
+
+}
+
 /**
  * Creates the main ui with all its buttons and stuff.
  */
@@ -953,4 +1085,7 @@ void initApplication(AppData *data) {
 
 	/* Show Default Window Window */
 	gtk_widget_show_all(GTK_WIDGET ( data->journeyWindow ));
+
+	/* Init GPS */
+	initGPS(data);
 }
