@@ -555,7 +555,7 @@ DetailInfo * mobilebahnde_parseSearchDetails(gchar *returnData) {
 					detailItem->timeToStr = g_strdup_printf(timeToStr);
 					detailItem->trainStr = g_strdup_printf(trainStr);
 					detailItem->infoStr = g_strdup_printf(infoStr);
-					detailItem->infoStr = g_strdup_printf(alternateStr);
+					detailItem->alternateStr = g_strdup_printf(alternateStr);
 
 					g_array_append_val (garray, detailItem);
 				}
